@@ -2,35 +2,13 @@
 #include <stdlib.h>
 #include <jansson.h>
 #define _HOEL_MARIADB
-#include "../include/hoel.h"
-
-/**
- * Implementation of sprintf that return a malloc'd char *  with the string construction
- * because life is too short to use 3 lines instead of 1
- * but don't forget to free the returned value after use!
- */
-char * cur_msprintf(const char * message, ...) {
-  va_list argp, argp_cpy;
-  size_t out_len = 0;
-  char * out = NULL;
-  va_start(argp, message);
-  va_copy(argp_cpy, argp);
-  out_len = vsnprintf(NULL, 0, message, argp);
-  out = malloc(out_len+sizeof(char));
-  if (out == NULL) {
-    return NULL;
-  }
-  vsnprintf(out, (out_len+sizeof(char)), message, argp_cpy);
-  va_end(argp);
-  va_end(argp_cpy);
-  return out;
-}
+#include <hoel.h>
 
 void print_result(struct _h_result result) {
   int col, row;
   char buf[64];
   int i;
-  printf("rows: %d, col: %d\n", result.nb_rows, result.nb_columns);
+  printf("rows: %u, col: %u\n", result.nb_rows, result.nb_columns);
   for (row = 0; row<result.nb_rows; row++) {
     for (col=0; col<result.nb_columns; col++) {
       switch(result.data[row][col].type) {
@@ -70,7 +48,8 @@ void unit_tests(struct _h_connection * conn) {
   char * query = NULL, * sanitized = NULL, * dump, * table = "other_test";
   int last_id = -1;
   
-  query = cur_msprintf("select * from %s", table);
+  // Execute a sql query and retrieve results in a json structure
+  query = msprintf("select * from %s", table);
   if (h_query_select_json(conn, query, &j_result) == H_OK) {
     dump = json_dumps(j_result, JSON_INDENT(2));
     printf("json result is\n%s\n", dump);
@@ -81,13 +60,14 @@ void unit_tests(struct _h_connection * conn) {
   }
   free(query);
   
+  // insert escaped string
   sanitized = h_escape_string(conn, "Hodor son of H'rtp'ss");
-  query = cur_msprintf("insert into %s (name, age, temperature, birthdate) values ('%s', %d, %f, '%s')", table, sanitized, 33, 37.2, "1412-03-08 12:00:22");
+  query = msprintf("insert into %s (name, age, temperature, birthdate) values ('%s', %d, %f, '%s')", table, sanitized, 33, 37.2, "1412-03-08 12:00:22");
   printf("insert result: %d\n", h_query_insert(conn, query));
   free(sanitized);
   free(query);
   
-  query = cur_msprintf("select * from %s", table);
+  query = msprintf("select * from %s", table);
   if (h_query_select(conn, query, &result) == H_OK) {
     print_result(result);
     h_clean_result(&result);
@@ -97,13 +77,12 @@ void unit_tests(struct _h_connection * conn) {
   free(query);
   
   sanitized = h_escape_string(conn, "Ygritte you know nothing");
-  query = cur_msprintf("insert into %s (name, age, temperature, birthdate) values ('%s', %d, %f, '%s')", table, sanitized, 25, 30.1, "1424-06-01 03:05:11");
+  query = msprintf("insert into %s (name, age, temperature, birthdate) values ('%s', %d, %f, '%s')", table, sanitized, 25, 30.1, "1424-06-01 03:05:11");
   printf("insert result: %d\n", h_query_insert(conn, query));
-  printf("COIN COIN COIN\n");
   free(sanitized);
   free(query);
   
-  query = cur_msprintf("select * from %s", table);
+  query = msprintf("select * from %s", table);
   if (h_query_select(conn, query, &result) == H_OK) {
     print_result(result);
     h_clean_result(&result);
@@ -113,7 +92,7 @@ void unit_tests(struct _h_connection * conn) {
   free(query);
   
   sanitized = h_escape_string(conn, "Littlefinger I will betray you");
-  query = cur_msprintf("insert into %s (name, age, temperature, birthdate) values ('%s', %d, %f, '%s')", table, sanitized, 44, 40.5, "1410-10-25 14:30:00");
+  query = msprintf("insert into %s (name, age, temperature, birthdate) values ('%s', %d, %f, '%s')", table, sanitized, 44, 40.5, "1410-10-25 14:30:00");
   printf("insert result: %d\n", h_query_insert(conn, query));
   free(sanitized);
   free(query);
@@ -124,7 +103,7 @@ void unit_tests(struct _h_connection * conn) {
   h_clean_data_full(data);
   printf("last id is %d\n", last_id);
   
-  query = cur_msprintf("select * from %s", table);
+  query = msprintf("select * from %s", table);
   if (h_query_select(conn, query, &result) == H_OK) {
     print_result(result);
     h_clean_result(&result);
@@ -134,12 +113,12 @@ void unit_tests(struct _h_connection * conn) {
   free(query);
   
   sanitized = h_escape_string(conn, "Littlefinger I am nothing");
-  query = cur_msprintf("update %s set name='%s' where id=%d", table, sanitized, last_id);
+  query = msprintf("update %s set name='%s' where id=%d", table, sanitized, last_id);
   printf("update result: %d\n", h_query_update(conn, query));
   free(sanitized);
   free(query);
 
-  query = cur_msprintf("select * from %s", table);
+  query = msprintf("select * from %s", table);
   if (h_query_select(conn, query, &result) == H_OK) {
     print_result(result);
     h_clean_result(&result);
@@ -148,11 +127,11 @@ void unit_tests(struct _h_connection * conn) {
   }
   free(query);
   
-  query = cur_msprintf("delete from %s where id=%d", table, last_id);
+  query = msprintf("delete from %s where id=%d", table, last_id);
   printf("delete result: %d\n", h_query_delete(conn, query));
   free(query);
   
-  query = cur_msprintf("select * from %s", table);
+  query = msprintf("select * from %s", table);
   if (h_query_select_json(conn, query, &j_result) == H_OK) {
     dump = json_dumps(j_result, JSON_INDENT(2));
     printf("json result is\n%s\n", dump);
