@@ -3,33 +3,11 @@
 #include <jansson.h>
 #include <yder.h>
 #define _HOEL_SQLITE
-#include "../include/hoel.h"
-
-/**
- * Implementation of sprintf that return a malloc'd char *  with the string construction
- * because life is too short to use 3 lines instead of 1
- * but don't forget to free the returned value after use!
- */
-char * msprintf(const char * message, ...) {
-  va_list argp, argp_cpy;
-  size_t out_len = 0;
-  char * out = NULL;
-  va_start(argp, message);
-  va_copy(argp_cpy, argp);
-  out_len = vsnprintf(NULL, 0, message, argp);
-  out = malloc(out_len+sizeof(char));
-  if (out == NULL) {
-    return NULL;
-  }
-  vsnprintf(out, (out_len+sizeof(char)), message, argp_cpy);
-  va_end(argp);
-  va_end(argp_cpy);
-  return out;
-}
+#include <hoel.h>
 
 void print_result(struct _h_result result) {
   int col, row, i;
-  printf("rows: %d, col: %d\n", result.nb_rows, result.nb_columns);
+  printf("rows: %u, col: %u\n", result.nb_rows, result.nb_columns);
   for (row = 0; row<result.nb_rows; row++) {
     for (col=0; col<result.nb_columns; col++) {
       switch(result.data[row][col].type) {
