@@ -24,7 +24,7 @@
 #ifndef __HOEL_H__
 #define __HOEL_H__
 
-#define HOEL_VERSION 1.4.4
+#include "hoel-cfg.h"
 
 #include <jansson.h>
 
@@ -102,6 +102,7 @@ struct _h_type_datetime {
  * sql value string type
  */
 struct _h_type_text {
+  size_t length;
   char * value;
 };
 
