@@ -145,7 +145,7 @@ int h_select_query_sqlite(const struct _h_connection * conn, const char * query,
               data = h_new_data_blob(sqlite3_column_blob(stmt, col), sqlite3_column_bytes(stmt, col));
               break;
             case SQLITE3_TEXT:
-              data = h_new_data_text((char*)sqlite3_column_text(stmt, col));
+              data = h_new_data_text((char*)sqlite3_column_text(stmt, col), sqlite3_column_bytes(stmt, col));
               break;
             case SQLITE_NULL:
               data = h_new_data_null();
@@ -285,13 +285,13 @@ int h_execute_query_json_sqlite(const struct _h_connection * conn, const char *
  */
 struct _h_connection * h_connect_sqlite(const char * db_path) {
   UNUSED(db_path);
-	y_log_message(Y_LOG_LEVEL_ERROR, "Hoel was not compiled with SQLite backend");
-	return NULL;
+  y_log_message(Y_LOG_LEVEL_ERROR, "Hoel was not compiled with SQLite backend");
+  return NULL;
 }
 
 void h_close_sqlite(struct _h_connection * conn) {
   UNUSED(conn);
-	y_log_message(Y_LOG_LEVEL_ERROR, "Hoel was not compiled with SQLite backend");
+  y_log_message(Y_LOG_LEVEL_ERROR, "Hoel was not compiled with SQLite backend");
 }
 
 #endif
