@@ -9,8 +9,10 @@
 #include <jansson.h>
 
 #include <check.h>
-#define _HOEL_SQLITE
-#include "../src/hoel.h"
+#ifndef  _HOEL_SQLITE
+  #define _HOEL_SQLITE
+#endif
+#include "hoel.h"
 
 #define DEFAULT_BD_PATH "/tmp/test.db"
 #define WRONG_BD_PATH "nope.db"
@@ -37,7 +39,7 @@ const char * db_path;
 
 void print_result(struct _h_result result) {
   int col, row, i;
-  printf("rows: %d, col: %d\n", result.nb_rows, result.nb_columns);
+  printf("rows: %u, col: %u\n", result.nb_rows, result.nb_columns);
   for (row = 0; row<result.nb_rows; row++) {
     for (col=0; col<result.nb_columns; col++) {
       switch(result.data[row][col].type) {
